Welcome to Merlin SDK documentation!
====================================

Make machine learning deployment magical.

Content
=======

.. toctree::
   :maxdepth: 2

   Introduction <introduction>
   Getting Started <getting_started>
   Sample Notebooks <sample/notebooks>

.. toctree::
   :maxdepth: 1
   :caption: Reference

    Python API reference <source/modules>